(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "tslib", "../util/fetch"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require("tslib");
    var fetch_1 = require("../util/fetch");
    function _parse(config) {
        var method = config.method || 'GET';
        var result = {
            params: '',
            done: config.done || defaultDone,
            fail: config.fail || defaultFail,
            options: {
                method: method
            }
        };
        // 注意 GET 或 HEAD 方法的请求不能包含 body 信息。
        if (method === 'GET' || method === 'HEAD') {
            _parseGet(config, result);
        }
        else {
            _parsePost(config, result);
        }
        return result;
    }
    function _parseGet(config, result) {
        // config.options.credentials = 'include'; // 携带 cookie
        // config.options.mode = "cors"; // 允许跨域
        if (!config.data) {
            return;
        }
        var i = 0;
        for (var key in config.data) {
            if (i === 0) {
                result.params += '?' + key + '=' + config.data[key];
            }
            else {
                result.params += '&' + key + '=' + config.data[key];
            }
            i++;
        }
    }
    function _parsePost(config, result) {
        result.options.credentials = 'same-origin';
        result.options.headers = { 'Content-type': 'application/json;charset=UTF-8' };
        result.options.body = JSON.stringify(config.data);
    }
    function defaultDone(data, status, responseInfo) { }
    function defaultFail(data, status, responseInfo) { }
    function doRequest(url, cfg) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, fetch_1.default(url + cfg.params, tslib_1.__assign({}, cfg.options))];
            });
        });
    }
    /**
     * 基于 fetch 的请求组件
     * @param config
     */
    function request(config) {
        var _this = this;
        var _a = config.url, url = _a === void 0 ? '' : _a, _b = config.done, done = _b === void 0 ? defaultDone : _b, _c = config.fail, fail = _c === void 0 ? defaultFail : _c;
        if (!url) {
            return false;
        }
        var cfg = _parse(config);
        doRequest(url, cfg).then(function (response) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var responseInfo;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, response.json()];
                    case 1:
                        responseInfo = _a.sent();
                        done && done(responseInfo.data, responseInfo.status, response);
                        return [2 /*return*/];
                }
            });
        }); }, function (error) {
            if (error.stack) {
                fail && fail(error.message, error.status, error);
            }
            else {
                fail && fail(error.data, error.status, error);
            }
        });
        return true;
    }
    exports.default = request;
});
//# sourceMappingURL=request.js.map